colour.colorimetry.illuminants Module — Colour 0.3.0 documentation

# colour.colorimetry.illuminants Module

## Illuminants

Defines CIE illuminants computation related objects.

See also

Illuminants IPython Notebook colour.colorimetry.dataset.illuminants.d_illuminants_s_spds, colour.colorimetry.spectrum.SpectralPowerDistribution

`colour.colorimetry.illuminants.` `D_illuminant_relative_spd`(xy)

  Returns the relative spectral power distribution of given CIE Standard Illuminant D Series using given xy chromaticity coordinates.

  References

  [1] | Wyszecki & Stiles, Color Science - Concepts and Methods Data and Formulae - Second Edition, Wiley Classics Library Edition, published 2000, ISBN-10: 0-471-39918-3, page 146.

  [2] | http://www.brucelindbloom.com/Eqn_DIlluminant.html (Last accessed 5 April 2014)

  Parameters: | xy (array_like) – xy chromaticity coordinates.
  Returns: | CIE Standard Illuminant D Series relative spectral power distribution.
  Return type: | SpectralPowerDistribution

  Examples

      >>> D_illuminant_relative_spd((0.34567, 0.35850))
      <colour.colorimetry.spectrum.SpectralPowerDistribution object at 0x...>